Site Manager Goals
==================

Provide an online collaboration environment for an organization or community
----------------------------------------------------------------------------

- :doc:`CreateCMFSite`

- :doc:`ConfigureCMFSite`

Maintain an overall site structure and organization
---------------------------------------------------

- :doc:`CreateCMFFolder`

- :doc:`CreateCMFTopic`

- **XXX**:doc:`ConfigureCMFTopic`

- **XXX**:doc:`ConfigureAllowedContentTypes`

Implement security policies for the site
----------------------------------------

- **XXX**:doc:`ConfigureObjectSecurity`

Implement workflow policies for the site
------------------------------------------

- **XXX** :doc:`AssociateWorkflowWithContentType`

Implement metadata policies for the site
----------------------------------------

- **XXX** :doc:`ConfigureRequiredMetadata`

Implement syndication policies for the site
-------------------------------------------

- **XXX** :doc:ConfigureContentSyndication

